pub struct ServerReflectionClient<T> { /* private fields */ }

Implementations

Compress requests with the given encoding.

This requires the server to support it otherwise it might respond with an error.

Enable decompressing responses.

The reflection service is structured as a bidirectional stream, ensuring all related requests go to a single server.