pub enum MessageRequest {
    FileByFilename(String),
    FileContainingSymbol(String),
    FileContainingExtension(ExtensionRequest),
    AllExtensionNumbersOfType(String),
    ListServices(String),
}
To use reflection service, the client should set one of the following fields in message_request. The server distinguishes requests by their defined field and then handles them using corresponding methods.

Variants



FileByFilename(String)

Find a proto file by the file name.



FileContainingSymbol(String)

Find the proto file that declares the given fully-qualified symbol name. This field should be a fully-qualified symbol name (e.g. .\[.\] or .).



FileContainingExtension(ExtensionRequest)

Find the proto file which defines an extension extending the given message type with the given field number.



AllExtensionNumbersOfType(String)

Finds the tag numbers used by all known extensions of extendee_type, and appends them to ExtensionNumberResponse in an undefined order. Its corresponding method is best-effort: it’s not guaranteed that the reflection service will implement this method, and it’s not guaranteed that this method will provide all extensions. Returns StatusCode::UNIMPLEMENTED if it’s not implemented. This field should be a fully-qualified type name. The format is .



ListServices(String)

List the full names of registered services. The content will not be checked.

Implementations

Encodes the message to a buffer.

Decodes an instance of the message from a buffer, and merges it into self.

Returns the encoded length of the message without a length delimiter.