pub enum MessageResponse {
    FileDescriptorResponse(FileDescriptorResponse),
    AllExtensionNumbersResponse(ExtensionNumberResponse),
    ListServicesResponse(ListServiceResponse),
    ErrorResponse(ErrorResponse),
}
The server sets one of the following fields according to the message_request in the request.

Variants



FileDescriptorResponse(FileDescriptorResponse)

This message is used to answer file_by_filename, file_containing_symbol, file_containing_extension requests with transitive dependencies. As the repeated label is not allowed in oneof fields, we use a FileDescriptorResponse message to encapsulate the repeated fields. The reflection service is allowed to avoid sending FileDescriptorProtos that were previously sent in response to earlier requests in the stream.



AllExtensionNumbersResponse(ExtensionNumberResponse)

This message is used to answer all_extension_numbers_of_type requests.



ListServicesResponse(ListServiceResponse)

This message is used to answer list_services requests.



ErrorResponse(ErrorResponse)

This message is used when an error occurs.

Implementations

Encodes the message to a buffer.

Decodes an instance of the message from a buffer, and merges it into self.

Returns the encoded length of the message without a length delimiter.