pub struct Builder<'b> { /* private fields */ }
A builder used to construct a gRPC Reflection Service.

Implementations

Create a new builder that can configure a gRPC Reflection Service.

Registers an instance of prost_types::FileDescriptorSet with the gRPC Reflection Service builder.

Registers a byte slice containing an encoded prost_types::FileDescriptorSet with the gRPC Reflection Service builder.

Serve the gRPC Reflection Service descriptor via the Reflection Service. This is enabled by default - set include to false to disable.

Advertise a fully-qualified gRPC service name.

If not called, then all services present in the registered file descriptor sets will be advertised.

Build a gRPC Reflection Service to be served via Tonic.