Module tonic_reflection::proto::server_reflection_request
source · Expand description
Nested message and enum types in ServerReflectionRequest.
Enums
To use reflection service, the client should set one of the following
fields in message_request. The server distinguishes requests by their
defined field and then handles them using corresponding methods.